@@ -4,7 +4,10 @@ APRS_SERVER_PORT_CLIENT_DEFINED_FILTERS = 14580
 
 APRS_APP_NAME = 'python-ogn-client'
 
-PACKAGE_VERSION = '0.4.0'
+PACKAGE_VERSION = '0.9.7'
 APRS_APP_VER = PACKAGE_VERSION[:3]
 
 APRS_KEEPALIVE_TIME = 240
+
+TELNET_SERVER_HOST = 'localhost'
+TELNET_SERVER_PORT = 50001
